summaryrefslogtreecommitdiff
path: root/zephyr/program/nissa/BUILD.py
diff options
context:
space:
mode:
Diffstat (limited to 'zephyr/program/nissa/BUILD.py')
-rw-r--r--zephyr/program/nissa/BUILD.py9
1 files changed, 8 insertions, 1 deletions
diff --git a/zephyr/program/nissa/BUILD.py b/zephyr/program/nissa/BUILD.py
index 00e4322473..0a10912552 100644
--- a/zephyr/program/nissa/BUILD.py
+++ b/zephyr/program/nissa/BUILD.py
@@ -4,7 +4,8 @@
"""Define zmake projects for nissa."""
# Nivviks and Craask, Pujjo, Xivu, Xivur, Uldren has NPCX993F, Nereid and Joxer, Yaviks has ITE81302
def register_nissa_project(
@@ -27,6 +28,7 @@ def register_nissa_project(
here / f"{chip_kconfig}_program.conf",
here / project_name / "project.conf",
],
+ inherited_from=["nissa"],
)
@@ -102,6 +104,11 @@ yaviks = register_nissa_project(
chip="it81302bx",
)
+yavilla = register_nissa_project(
+ project_name="yavilla",
+ chip="it81302bx",
+)
+
uldren = register_nissa_project(
project_name="uldren",
chip="npcx9m3f",
@@ -4,7 +4,8 @@
"""Define zmake projects for nissa."""
-# Nivviks and Craask, Pujjo, Xivu, Xivur, Uldren has NPCX993F, Nereid and Joxer, Yaviks has ITE81302
+# Nivviks and Craask, Pujjo, Xivu, Xivur, Uldren has NPCX993F, Nereid
+# and Joxer, Yaviks, Yavilla has ITE81302
def register_nissa_project(